@@ -4,13 +4,17 @@ use warnings;
 use 5.010; # state
 
 # ABSTRACT: Fully UTF-8 aware Cwd
-our $VERSION = '0.008'; # VERSION
+our $VERSION = '0.009'; # VERSION
 
-#pod =head1 SYNOPSIS
+#pod =begin :prelude
 #pod
 #pod =for test_synopsis
 #pod my $file;
 #pod
+#pod =end :prelude
+#pod
+#pod =head1 SYNOPSIS
+#pod
 #pod     # Using the utf-8 versions of cwd, getcwd, fastcwd, fastgetcwd
 #pod     use Cwd::utf8;
 #pod     my $dir = getcwd;
@@ -92,7 +96,7 @@ $Carp::Internal{$current_package}++; # To get warnings reported at correct calle
 #pod
 #pod =cut
 
-our $UTF8_CHECK = Encode::FB_CROAK; # Die on encoding errors
+our $UTF8_CHECK = Encode::FB_CROAK | Encode::LEAVE_SRC; # Die on encoding errors
 
 # UTF-8 Encoding object
 my $_UTF8 = Encode::find_encoding('UTF-8');
@@ -139,14 +143,12 @@ sub unimport { ## no critic (Subroutines::ProhibitBuiltinHomonyms)
 sub _utf8_cwd {
     my $func = shift;
 
-    # Enforce LEAVE_SRC
-    $UTF8_CHECK |= Encode::LEAVE_SRC if $UTF8_CHECK;
-
     my $hints = (caller 1)[10]; # Use caller level 1 because of the added anonymous sub around call
     if (! $hints->{$current_package}) {
         # Use original function if we're not using Cwd::utf8 in calling package
         return $_orig_functions{$func}->(@_);
     } else {
+        $UTF8_CHECK |= Encode::LEAVE_SRC if $UTF8_CHECK; # Enforce LEAVE_SRC
         my @args = map { $_ ? $_UTF8->encode($_, $UTF8_CHECK) : $_ } @_;
         if (wantarray) {
             return map { $_ ? $_UTF8->decode($_, $UTF8_CHECK) : $_ } $_orig_functions{$func}->(@args);
@@ -171,10 +173,24 @@ Cwd::utf8 - Fully UTF-8 aware Cwd
 
 =head1 VERSION
 
-version 0.008
+version 0.009
+
+=for test_synopsis my $file;
 
 =head1 SYNOPSIS
 
+    # Using the utf-8 versions of cwd, getcwd, fastcwd, fastgetcwd
+    use Cwd::utf8;
+    my $dir = getcwd;
+
+    # Using the utf-8 versions of abs_path
+    use Cwd::utf8 qw(abs_path);
+    my $abs_path = abs_path($file);
+
+    # Exporting no functions
+    use Cwd::utf8 qw(:none); # NOT "use Cwd::utf8 qw();"!
+    my $real_path = Cwd::real_path($file);
+
 =head1 DESCRIPTION
 
 While the original L<Cwd> functions are capable of handling UTF-8
@@ -210,20 +226,6 @@ the encoding errors as warnings, and C<Encode::FB_DEFAULT> will completely
 ignore them. Please see L<Encode> for details. Note: C<Encode::LEAVE_SRC> is
 I<always> enforced.
 
-=for test_synopsis my $file;
-
-    # Using the utf-8 versions of cwd, getcwd, fastcwd, fastgetcwd
-    use Cwd::utf8;
-    my $dir = getcwd;
-
-    # Using the utf-8 versions of abs_path
-    use Cwd::utf8 qw(abs_path);
-    my $abs_path = abs_path($file);
-
-    # Exporting no functions
-    use Cwd::utf8 qw(:none); # NOT "use Cwd::utf8 qw();"!
-    my $real_path = Cwd::real_path($file);
-
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker
@@ -259,7 +261,7 @@ L<utf8::all> -- Turn on utf-8, all of it. This was also the module I first added
 
 =head1 AUTHOR
 
-Hayo Baan <hayobaan@cpan.org>
+Hayo Baan <info@hayobaan.com>
 
 =head1 COPYRIGHT AND LICENSE
 
